import 'dart:async';
import 'dart:html';

import 'package:angular/angular.dart';

/// An enumeration of Bootstrap viewport sizes.
enum BootstrapSize {
    xs,
    sm,
    md,
    lg
}

/// A service for manipulating global (i.e. document level) state.
@Injectable()
class DocumentService {
    BootstrapSize _bsize;
    StreamController<BootstrapSize> _bsizeController;
    String _title;

    /// Bootstrap size property.
    BootstrapSize get bootstrapSize => this._bsize;

    void set bootstrapSize(BootstrapSize bsize) {
        if (bsize != this._bsize) {
            this._bsize = bsize;
            this._bsizeController.add(bsize);
        }
    }

    /// Document title property.
    String get title => this._title;

    void set title(String t) {
        /// Dart analyzer needs some help with window.document: it thinks it
        /// doesn't have a title property, but it actually does.
        (window.document as HtmlDocument).title = '$t — Starbelly';
    }

    /// Bootstrap size event stream.
    Stream<BootstrapSize> get onBootstrapSize => this._bsizeController.stream;

    /// Constructor.
    DocumentService() {
        this.title = 'Loading…';
        this._bsizeController = new StreamController<BootstrapSize>();
    }
}
